#
# spec file for package tnt
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tnt
Version:        1.9.2
Release:        lp152.25.3
Summary:        Terminal program for packet radio
License:        GPL-2.0-only
Group:          Productivity/Hamradio/Packet
URL:            http://www.wspse.de/WSPse/Packet.php3
Source:         ftp://ftp.wspse.de/pub/packet_radio/tnt/CVS/tnt-1.9.2.tar.bz2
Source99:       tnt-rpmlintrc
Patch0:         tnt-%{version}-install.dif
Patch1:         tnt-window.dif
Patch2:         tnt_bufferoverflows.diff
Patch3:         tnt-%{version}-configure-header-check.dif
Patch4:         tnt-%{version}-gettext-0_18.dif
Patch5:         tnt-%{version}-gettext-0_19.dif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  libax25-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  texinfo
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}
%if 0%{?suse_version} <= 1230
BuildRequires:  sysvinit
%endif

%description
TNT is a console based packet radio terminal for hostmode tncs. It
supports virtual channels and socket communication. It also can be used
with ax25 kernel or kiss interfaces together with TFkiss.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
# gettext 0.18 for openSUSE==13.1
%if 0%{?suse_version} == 1310
%patch4 -p1
%endif
# gettext 0.19 for openSUSE>13.1 (Note: 1315 = Leap 42.1)
%if 0%{?suse_version} > 1310
%patch5 -p1
%endif

%build
autoreconf -fiv
test -f po/Makevars || mv po/Makevars.template po/Makevars
%configure \
  --enable-ax25k2 \
  --enable-hibaud
# --enable-dpboxt
make %{?_smp_mflags}

%install
%make_install
rm -f examples/Makefile* examples/*.in examples/sounds/Makefile* examples/sounds/*.in
%find_lang %{name}
%fdupes -s %{buildroot}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/tntdoc.info.gz
%install_info --info-dir=%{_infodir} %{_infodir}/tntdoc.info-1.gz
%install_info --info-dir=%{_infodir} %{_infodir}/tntdoc.info-2.gz
%install_info --info-dir=%{_infodir} %{_infodir}/tntdoc.info-3.gz
%install_info --info-dir=%{_infodir} %{_infodir}/tntdoc.info-4.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/tntdoc.info.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/tntdoc.info-1.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/tntdoc.info-2.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/tntdoc.info-3.gz
%install_info_delete --info-dir=%{_infodir} %{_infodir}/tntdoc.info-4.gz

%files
%license COPYING
%doc AUTHORS AX25-NOTES ChangeLog NEWS README TODO
%{_bindir}/tnt
%{_bindir}/tntc
%{_sbindir}/tnt_setup.*
%{_includedir}/tntrun.h
%{_infodir}/tntdoc.info*
%{_prefix}/lib/tnt/
%dir %{_datadir}/tnt/
%config %{_datadir}/tnt/conf/
%{_datadir}/tnt/doc/
%{_datadir}/tnt/sounds/
%{_localstatedir}/spool/tnt/

%files lang -f %{name}.lang
%changelog
* Sun Feb 24 2019 Martin Hauke <mardnh@gmx.de>
- Specfile cleanup
  * Drop all unneeded build-dependencies
  * Use %%configure macro
  * Run spec-cleaner
- Add tnt-rpmlintrc
- Convert inline changelog to tnt.changes
* Tue Apr 12 2016 arnd@gronenberg.com
- fixed gettext version handling
* Mon Apr 11 2016 arnd@gronenberg.com
- changed buildrequires for openSUSE 13.1+
- updated gettext version (AM_GNU_GETTEXT_VERSION) to 0.19
- fixed spec file for current rpmbuild
* Tue Mar  1 2011 dg7gt@gmx.de
- changed buildrequires for OpenSUSE 11.4
* Wed Jul 14 2010 dg7gt@gmx.de
- SPEC File corrections for OpenSUSE 11.3
- additional header check includes added in configure.in
* Mon Dec 18 2006 dg7gt@online.de
- updated to version 1.9.2
* Mon May 17 2004 jreuter@suse.de
- added missing include of time.h
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Jun 19 2003 ro@suse.de
- build with current gettext
* Wed Jun 18 2003 ro@suse.de
- added directory to filelist
* Mon Nov 18 2002 schwab@suse.de
- Add AM_GNU_GETTEXT_VERSION.
* Thu Apr 25 2002 ro@suse.de
- fix for latest gettext and automake
* Mon Nov 19 2001 ro@suse.de
- fixed for automake 1.5
* Tue Jun 19 2001 jreuter@suse.de
- doesn't include kernel headers anymore
* Tue Jun 12 2001 jreuter@suse.de
- added 'aclocal' for autoconf to work again
- removed program prefix from configure parameter
* Wed May  9 2001 mfabian@suse.de
- bzip2 sources
* Thu Apr 12 2001 ro@suse.de
- gettextize to compile
* Mon Feb 19 2001 uli@suse.de
- fixed for new glibc
* Thu Nov 30 2000 jreuter@suse.de
- changed group to Applications/Hamradio
* Fri Nov 17 2000 ro@suse.de
- compile fix
* Tue Jun 27 2000 schwab@suse.de
- Add %%%%suse_update_config.
- Fix missing declarations.
* Fri Jun  9 2000 bubnikv@suse.cz
- updated to 1.9.1
* Mon Feb 28 2000 kukuk@suse.de
- Move %%{_prefix}/libexec/tnt %%{_prefix}/lib/tnt
- Move %%{_prefix}/info -> %%{_infodir}
* Mon Oct 25 1999 ka@suse.de
- initial release
- configured with --with-included-gettext --enable-ax25k2 \
--enable-hibaud
